@@ -155,6 +155,9 @@ class LoggerGenerator:
         if self._FILENAME is None:
             self._FILENAME = f"{self._LOG_FOLDER}{year}{month}{day}-{hour}{minute}{second}_{self._split_cnt}.log"
 
+        else:
+            self._FILENAME = f"{self._LOG_FOLDER}{self._FILENAME}"
+
         self._log = self._get_log()
 
     def _get_log(self) -> logging.Logger:
